/*
 * $Id$
 * Author: Karoly Bosa
 *
 * (C) 2010 by Research Institute for Symbolic Computation, Linz, Austria
 * All rights reserved. See COPYRIGHT in top-level directory.
 */

#ifndef LATENCYCLUSTER_H_
#define LATENCYCLUSTER_H_

#include <stdio.h>
#include <stdlib.h>
#include <vector>
#include <taag_errno.h>
#include "HostData.h"
#include "GroupData.h"
#include "ProcsDistribution.h"

using namespace std;

class LatencyCluster {
	private :
		int level;
		bool contained;
		bool chosen;
		bool alreadyChosen;
		vector<HostData *> hostList;
		vector<LatencyCluster *> clusterList;

	public :
		LatencyCluster();
		LatencyCluster(int _level);
		virtual ~LatencyCluster();
		bool isEmpty();
		int addHost(HostData *newHost);
		int getNrOfHosts();
		double getNrOfCPUs();

		int getProcsCapacity();
		bool areEnoughProcsCapacity(int nrOfProcs);
		bool mapGroupToHosts(GroupData *grp);
		bool mapMgrsToHosts(ProcsDistribution *pd, int firstMgrIndex);
		void setLevel(int _level);
		int getLevel();
		HostData *getHostByIndex(unsigned int index);
		void printOutLatencyCluster(FILE *f);

		void setContained();
		bool isContained();
		void setChosen(bool value);
		bool isChosen();
		bool wasChosen();
		int addCluster(LatencyCluster *newCluster);
		//int getNrOfCluster();
		//LatencyCluster *getClusterByIndex(unsigned int index);
		void collectHostsFromContainedClusters();
};

#endif /* LATENCYCLUSTER_H_ */
