/*
 * $Id$
 * Author: Karoly Bosa
 *
 * (C) 2010 by Research Institute for Symbolic Computation, Linz, Austria
 * All rights reserved. See COPYRIGHT in top-level directory.
 */

#include "LatencyMatrix.h"

LatencyMatrix::LatencyMatrix(int _size) {
	size = _size;
	latencyMatrix = new LatencyValue[size*size];
}

LatencyMatrix::~LatencyMatrix() {
	delete[] latencyMatrix;
}

void LatencyMatrix::initValue(double value1to2, double value2to1, int hostIndex1, int hostIndex2) {
	if (hostIndex1<0 || hostIndex2<0 || hostIndex1>=size || hostIndex2>=size) return;
	latencyMatrix[hostIndex1*size+hostIndex2].initValues(value1to2, value2to1, hostIndex1, hostIndex2);
	latencyMatrix[hostIndex2*size+hostIndex1].initValues(value2to1, value1to2, hostIndex2, hostIndex1);
}

LatencyValue *LatencyMatrix::getValue(int index1, int index2) {
	if (index1<0 || index2<0 || index1>=size || index2>=size) {
		return NULL;
	}
	return &latencyMatrix[index1*size+index2];
}

void LatencyMatrix::printOutLatencyMatrix(FILE *f) {
	for (int i=0; i<size; i++) {
		for (int j=0; j<size; j++) {
			fprintf(f, "  %.4f",latencyMatrix[i*size+j].getValue());
		}
		fprintf(f, "\n");
	}
}
